==> giga-0.0.2.tar.gz: giga-0.0.2/giga/configs/updatedb.py <==
import giga
import io
from giga import configs

log = giga.logs.get_logger(__name__)

class Prunes(giga.Config):
  'Apply PRUNEPATHS to /etc/updatedb.conf.'

  paths = None
  conf = '/etc/updatedb.conf'
  keep = False
  config_logger = log

  def on_apply(self):
    super().on_apply()
    sys = self.system
    with self.task(f'Apply {len(self.paths)} updatedb prunes') as task:
      if sys.isfile(self.conf):
        with io.StringIO(sys.loads(self.conf)) as conf, io.StringIO() as buf:
          for line in conf:
            if line.startswith('PRUNEPATHS='):
              paths = line.strip().split('=', 1)[1][1:-1].split(' ')
              paths += [path for path in self.paths if path not in paths]
              paths = ' '.join(paths)
              line = f'PRUNEPATHS="{paths}"\n'
            buf.write(line)
          task.ensure.fs.contents(self.conf, buf.getvalue())

  def on_delete(self):
    super().on_delete()
    sys = self.system
    with self.task('Delete updatedb prune') as task:
      if not self.keep:
        if sys.isfile(self.conf):
          with io.StringIO(sys.loads(self.conf)) as conf, io.StringIO() as buf:
            for line in conf:
              if line.startswith('PRUNEPATHS='):
                paths = line.strip().split('=', 1)[1][1:-1].split(' ')
                paths = [path for path in paths if path not in self.paths]
                paths = ' '.join(paths)
                line = f'PRUNEPATHS="{paths}"\n'
              buf.write(line)
            task.ensure.fs.contents('/etc/updatedb.conf', buf.getvalue())

  def on_is_applied(self):
    sys = self.system
    if super().on_is_applied():
      if sys.isfile(self.conf):
        with io.StringIO(sys.loads(self.conf)) as conf:
          for line in conf:
            if line.startswith('PRUNEPATHS='):
              paths = line.strip().split('=', 1)[1][1:-1].split(' ')
              return all(path in paths for path in self.paths)
          else:
            # PRUNEPATHS not in updatedb.conf. something is broken and we
            # shouldn't mess with it
            return True
    return False

==> giga-0.0.3.tar.gz: giga-0.0.3/giga/configs/updatedb.py <==
import giga
import io
import logging

log = logging.getLogger(__name__)

class Prunes(giga.Config):
  'Apply PRUNEPATHS to /etc/updatedb.conf.'

  paths = None
  conf = '/etc/updatedb.conf'
  keep = False

  def on_apply(self):
    super().on_apply()
    sys = self.system
    with giga.Task(f'Apply {len(self.paths)} updatedb prunes') as task:
      if sys.isfile(self.conf):
        with io.StringIO(sys.loads(self.conf)) as conf, io.StringIO() as buf:
          for line in conf:
            if line.startswith('PRUNEPATHS='):
              paths = line.strip().split('=', 1)[1][1:-1].split(' ')
              paths += [path for path in self.paths if path not in paths]
              paths = ' '.join(paths)
              line = f'PRUNEPATHS="{paths}"\n'
            buf.write(line)
          giga.ensure.fs.contents.present([(self.conf, buf.getvalue())])

  def on_delete(self):
    super().on_delete()
    sys = self.system
    with giga.Task('Delete updatedb prune') as task:
      if not self.keep:
        if sys.isfile(self.conf):
          with io.StringIO(sys.loads(self.conf)) as conf, io.StringIO() as buf:
            for line in conf:
              if line.startswith('PRUNEPATHS='):
                paths = line.strip().split('=', 1)[1][1:-1].split(' ')
                paths = [path for path in paths if path not in self.paths]
                paths = ' '.join(paths)
                line = f'PRUNEPATHS="{paths}"\n'
              buf.write(line)
            paths = ('/etc/updatedb.conf', buf.getvalue()),
          giga.ensure.fs.contents.present(paths)

  def on_is_applied(self):
    sys = self.system
    if super().on_is_applied():
      if sys.isfile(self.conf):
        with io.StringIO(sys.loads(self.conf)) as conf:
          for line in conf:
            if line.startswith('PRUNEPATHS='):
              paths = line.strip().split('=', 1)[1][1:-1].split(' ')
              return all(path in paths for path in self.paths)
          else:
            # PRUNEPATHS not in updatedb.conf. something is broken and we
            # shouldn't mess with it
            return True
    return False

giga.utils.set_config_logger(__name__, log)
